searchNodes=[{"doc":"Provides glob expressions for Elixir. A glob expression looks like an ordinary path, except that the following &quot;wildcard characters&quot; are interpreted in a special way: ? - matches one character. * - matches any number of characters up to the end of the filename, the next dot, or the next slash. ** - two adjacent * 's used as a single pattern will match all files and zero or more directories and subdirectories. [char1,char2,...] - matches any of the characters listed; two characters separated by a hyphen will match a range of characters. Do not add spaces before and after the comma as it would then match paths containing the space character itself. {item1,item2,...} - matches one of the alternatives. Do not add spaces before and after the comma as it would then match paths containing the space character itself. Other characters represent themselves. Only paths that have exactly the same character in the same position will match. Note that matching is case-sensitive: &quot;a&quot; will not match &quot;A&quot; . Directory separators must always be written as / , even on Windows. You may call Path.expand/1 to normalize the path before invoking this function. A character preceded by loses its special meaning. Note that must be written as \\ in a string literal. For example, &quot;\\?*&quot; will match any filename starting with ?. Glob expressions in can be created using compile/2 , compile!/2 or the sigils ~g (see GlobEx.Sigils.sigil_g/2 ) or ~G (see GlobEx.Sigils.sigil_G/2 ). # A simple glob expressions matching all `.exs` files in a tree. By default, # the patterns `*` and `?` do not match files starting with a `.`. ~g|**/*.exs| # The modifier `d` let the glob treat files starting with a `.` as any other # file. ~g|**/*.exs|d","ref":"GlobEx.html","title":"GlobEx","type":"module"},{"doc":"Compiles the glob expression. It returns {:ok, regex} in case of success, {:error, reason} otherwise. See the module documentation for how to write a glob expression. By default, the patterns * and ? do not match files starting with a . . This behaviour can be change with the option :match_dot . Options :match_dot - (boolean) if false , the special wildcard characters * and ? will not match files starting with a . . If true , files starting with a . will not be treated specially. Defaults to false . Examples iex&gt; GlobEx . compile ( &quot;src/**/?oo.ex&quot; ) { :ok , ~g|src/**/?oo.ex| } iex&gt; GlobEx . compile ( &quot;src/{a,b/?oo.ex&quot; ) { :error , % GlobEx.CompileError { reason : { :missing_delimiter , 5 } } }","ref":"GlobEx.html#compile/2","title":"GlobEx.compile/2","type":"function"},{"doc":"Compiles the glob expression and raises GlobEx.CompileError in case of errors. See the module documentation for how to write a glob expression and compile/2 for the available options.","ref":"GlobEx.html#compile!/2","title":"GlobEx.compile!/2","type":"function"},{"doc":"Traverses paths according to the given glob expression and returns a list of matches. See the module documentation for how to write a glob expression. Examples iex&gt; GlobEx . ls ( ~g|{lib,test}/**/*.{ex,exs}| ) [ &quot;lib/glob_ex.ex&quot; , &quot;lib/glob_ex/compiler.ex&quot; , &quot;lib/glob_ex/compiler_error.ex&quot; , &quot;lib/glob_ex/sigils.ex&quot; , &quot;test/glob_ex/compiler_test.exs&quot; , &quot;test/glob_ex_test.exs&quot; , &quot;test/test_helper.exs&quot; ]","ref":"GlobEx.html#ls/1","title":"GlobEx.ls/1","type":"function"},{"doc":"Returns a boolean indicating whether there was a match or not. See the module documentation for how to write a glob expression. Examples iex&gt; GlobEx . match? ( ~g|{lib,test}/**/*.{ex,exs}| , &quot;lib/foo/bar.ex&quot; ) true iex&gt; GlobEx . match? ( ~g|{lib,test}/**/*.{ex,exs}| , &quot;lib/foo/bar.java&quot; ) false","ref":"GlobEx.html#match?/2","title":"GlobEx.match?/2","type":"function"},{"doc":"","ref":"GlobEx.html#t:t/0","title":"GlobEx.t/0","type":"type"},{"doc":"This module provides the sigils ~g|| and ~G|| .","ref":"GlobEx.Sigils.html","title":"GlobEx.Sigils","type":"module"},{"doc":"Handles the sigil ~G for globs. It returns a glob expression pattern without interpolations and without escape characters. See the module documentation GlobEx for how to write a glob expression. Examples iex&gt; ~G|*.txt| ~g|*.txt| iex&gt; GlobEx . match? ( ~G|f\#{a,b}| , &quot;f#a&quot; ) true","ref":"GlobEx.Sigils.html#sigil_G/2","title":"GlobEx.Sigils.sigil_G/2","type":"macro"},{"doc":"Handles the sigil ~g for globs. See the module documentation GlobEx for how to write a glob expression. Examples iex&gt; ~g|*.txt| ~g|*.txt| iex&gt; ~g|*. \#{ &quot;txt&quot; } | ~g|*.txt| iex&gt; GlobEx . match? ( ~g|f \\# {a,b}| , &quot;f#a&quot; ) true","ref":"GlobEx.Sigils.html#sigil_g/2","title":"GlobEx.Sigils.sigil_g/2","type":"macro"},{"doc":"TODO","ref":"GlobEx.CompileError.html","title":"GlobEx.CompileError","type":"exception"},{"doc":"","ref":"GlobEx.CompileError.html#t:reason/0","title":"GlobEx.CompileError.reason/0","type":"type"},{"doc":"","ref":"GlobEx.CompileError.html#t:t/0","title":"GlobEx.CompileError.t/0","type":"type"}]